@@ -158,7 +158,13 @@ class OrderByTuple(tuple, StrAndUnicode):
         """
         def _cmp(a, b):
             for accessor, reverse in instructions:
-                res = cmp(accessor.resolve(a), accessor.resolve(b))
+                x = accessor.resolve(a)
+                y = accessor.resolve(b)
+                try:
+                    res = cmp(x, y)
+                except TypeError:
+                    res = cmp((repr(x.__class__), id(x.__class__), x),
+                              (repr(y.__class__), id(y.__class__), y))
                 if res != 0:
                     return -res if reverse else res
             return 0
